<?php

ini_set('display_errors', true);

class nl2goApi extends oxUBase
{

    public function getCustomers()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $params = array();
        $params['hours'] = $this->getConfig()->getRequestParameter('hours');
        $params['subscribed'] = $this->getConfig()->getRequestParameter('subscribed');
        $params['offset'] = $this->getConfig()->getRequestParameter('offset');
        $params['limit'] = $this->getConfig()->getRequestParameter('limit');
        $params['groups'] = $this->getConfig()->getRequestParameter('groups', true);
        $params['fields'] = $this->getConfig()->getRequestParameter('fields', true);

        $model = oxNew('nl2gomodel');
        $customers = $model->getCustomers($params);
        $result = array(
            'success' => 1,
            'message' => 'OK',
            'customers' => $customers['data'],
            'results' => count($customers['data']),
            'total' => $customers['total'],
        );

        $this->sendResponse(json_encode($result));
    }

    public function getGroups()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $model = oxNew('nl2gomodel');
        $groups = $model->getCustomerGroups();
        $result = array(
            'success' => 1,
            'message' => 'OK',
            'groups' => $groups,
        );

        $this->sendResponse(json_encode($result));
    }

    public function getFields()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $model = oxNew('nl2gomodel');
        $fields = $model->getCustomerFields();
        $result = array(
            'success' => 1,
            'message' => 'OK',
            'fields' => $fields,
        );

        $this->sendResponse(json_encode($result));
    }

    public function getAttributes()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $model = oxNew('nl2gomodel');
        $attributes = $model->getProductAttributes();
        $result = array(
            'success' => 1,
            'message' => 'OK',
            'attributes' => $attributes,
        );

        $this->sendResponse(json_encode($result));
    }

    public function getProductInfo()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $params = array();
        $params['lang'] = $this->getConfig()->getRequestParameter('lang');
        $params['id'] = $this->getConfig()->getRequestParameter('id');
        if (!$params['lang'] || !$params['id']) {
            $this->sendResponse(json_encode(array('success' => 0, 'message' => 'Parameters lang and/or id not found!')));
        }

        if (array_search($params['lang'], oxRegistry::getLang()->getActiveShopLanguageIds()) === false) {
            $this->sendResponse(json_encode(array('success' => 0, 'message' => 'Language not found/supported!')));
        }

        $params['attributes'] = $this->getConfig()->getRequestParameter('attributes', true);

        $model = oxNew('nl2gomodel');
        $product = $model->getProductInfo($params);
        $result = array(
            'success' => 1,
            'message' => 'OK',
            'product' => $product,
        );

        $this->sendResponse(json_encode($result));
    }

    public function unsubscribeCustomer()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $email = $this->getConfig()->getRequestParameter('email');
        if (!$email) {
            $this->sendResponse(json_encode(array('success' => 0, 'message' => 'Email parameter not found!')));
        }

        $model = oxNew('nl2gomodel');
        $unsubscribed = $model->unsubscribeCustomer($email);
        $message = $unsubscribed ? 'Customer has been unsubscribed successfully' : 'No customer has been unsubscribed!';

        $this->sendResponse(json_encode(array('success' => $unsubscribed, 'message' => $message)));
    }
    
    public function setBounce()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $email = $this->getConfig()->getRequestParameter('email');
        if (!$email) {
            $this->sendResponse(json_encode(array('success' => 0, 'message' => 'Email parameter not found!')));
        }

        $model = oxNew('nl2gomodel');
        $bounce = $model->bounceEmail($email);
        $message = $bounce ? 'Bounce flag has been set successfully' : 'Faild to set bounce flag!';

        $this->sendResponse(json_encode(array('success' => $bounce, 'message' => $message)));
    }

    public function testConnection()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }

        $this->sendResponse(json_encode(array('success' => 1, 'message' => 'Connected!')));
    }
    
    public function getVersion()
    {
        if (!$this->authenticate()) {
            $this->errorAuthentication();
        }
        
        require_once __DIR__ . '/../metadata.php';
        
        $this->sendResponse(json_encode(array('success' => 1, 'message' => 'OK', 'version' => str_replace('.','',$sMetadataVersion))));
    }

    protected function authenticate()
    {
        $config = $this->getConfig();
        $myUtilsServer = oxRegistry::get("oxUtilsServer");

        $username = $myUtilsServer->getServerVar('PHP_AUTH_USER') ? $myUtilsServer->getServerVar('PHP_AUTH_USER')
                : $this->getConfig()->getRequestParameter('username');
        $apiKey = $myUtilsServer->getServerVar('PHP_AUTH_PW') ? $myUtilsServer->getServerVar('PHP_AUTH_PW')
                : $this->getConfig()->getRequestParameter('apikey');

        return ($username == $config->getConfigParam('nl2goUserName') && $apiKey == $config->getConfigParam('nl2goApiKey'));
    }

    protected function errorAuthentication()
    {
        $result = array('success' => 0, 'message' => 'Authentication faild!');
        $this->sendResponse(json_encode($result));
    }

    protected function sendResponse($data = array())
    {
        oxRegistry::getUtils()->setHeader('Content-Type: application/json;');
        oxRegistry::getUtils()->showMessageAndExit($data);
    }

}
